@@ -16,7 +16,11 @@ var.probit <- function(p, n = 1) {
   p * (1 - p)/n/dnorm(z)^2
 }
 
+binom.lchoose <- function(n, x) {
+  lgamma(n + 1) - lgamma(n - x + 1) - lgamma(x + 1)
+}
+
 ldbinom <- function(x, size, prob, log = TRUE) {
-  log.f <- lchoose(size, x) + x * log(prob) + (size - x) * log(1 - prob)
+  log.f <- binom.lchoose(size, x) + x * log(prob) + (size - x) * log(1 - prob)
   if(log) log.f else exp(log.f)
 }
